pub struct AdaptiveMovingAverage {
pub period_efficiency_ratio: usize,
pub period_fast: usize,
pub period_slow: usize,
pub price_type: PriceType,
pub value: f64,
pub count: usize,
pub initialized: bool,
/* private fields */
}Expand description
An indicator which calculates an adaptive moving average (AMA) across a rolling window. Developed by Perry Kaufman, the AMA is a moving average designed to account for market noise and volatility. The AMA will closely follow prices when the price swings are relatively small and the noise is low. The AMA will increase lag when the price swings increase.
Fields
period_efficiency_ratio: usizeThe period for the internal EfficiencyRatio indicator.
period_fast: usizeThe period for the fast smoothing constant (> 0).
period_slow: usizeThe period for the slow smoothing constant (> period_fast).
price_type: PriceTypeThe price type used for calculations.
value: f64The last indicator value.
count: usizeThe input count for the indicator.
initialized: boolImplementations
Sourceimpl AdaptiveMovingAverage
impl AdaptiveMovingAverage
Sourcepub fn new(
period_efficiency_ratio: usize,
period_fast: usize,
period_slow: usize,
price_type: Option<PriceType>,
) -> Self
pub fn new( period_efficiency_ratio: usize, period_fast: usize, period_slow: usize, price_type: Option<PriceType>, ) -> Self
Creates a new AdaptiveMovingAverage instance.
Panics
This function panics if:
period_efficiency_ratio== 0.period_fast== 0.period_slow== 0.period_slow≤period_fast.
pub fn alpha_diff(&self) -> f64
pub const fn reset(&mut self)
Sourceimpl AdaptiveMovingAverage
impl AdaptiveMovingAverage
Sourcepub fn py_new(
period_efficiency_ratio: usize,
period_fast: usize,
period_slow: usize,
price_type: Option<PriceType>,
) -> Self
pub fn py_new( period_efficiency_ratio: usize, period_fast: usize, period_slow: usize, price_type: Option<PriceType>, ) -> Self
An indicator which calculates an adaptive moving average (AMA) across a rolling window. Developed by Perry Kaufman, the AMA is a moving average designed to account for market noise and volatility. The AMA will closely follow prices when the price swings are relatively small and the noise is low. The AMA will increase lag when the price swings increase.